%define oname   The-Powder-Toy

Name:           powdertoy
Version:        96.2.350
Release:        %mkrel 1
Summary:        Falling-sand physics sandbox game
Group:          Games/Simulation
License:        GPLv3+
Url:            http://powdertoy.co.uk
Source0:        https://github.com/simtr/The-Powder-Toy/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  meson
BuildRequires:  ninja

%description
The Powder Toy is a free physics sandbox game, which simulates
air pressure and velocity, heat, gravity and a countless number
of interactions between different substances! The game provides
you with various building materials, liquids, gases and electronic
components which can be used to construct complex machines, guns,
bombs, realistic terrains and almost anything else.

%prep
%setup -q -n %{oname}-%{version}
%autopatch -p1

%build
%set_build_flags
export CPPDEFINES="NO_INSTALL_CHECK"
%meson \
	-Dlua=luajit \
%ifnarch x86_64
	-Dx86_sse=none \
%endif
%nil
%meson_build

%install
%meson_install

# Game binary
install -D -m755 build/powder %{buildroot}%{_libexecdir}/%{name}/powder

# Wrapper script
cat << EOF > %{name}.sh
#!/bin/sh
CONFIGDIR=\$HOME"/.config/%{name}"

if [ ! -e \$CONFIGDIR ];
then
    echo -e "Creating the config directory for The Powder Toy in\n\$CONFIGDIR"
    mkdir -p \$CONFIGDIR
fi

pushd \$CONFIGDIR
exec %{_libexecdir}/%{name}/powder \$@
popd
EOF

install -D -m755 %{name}.sh %{buildroot}%{_gamesbindir}/%{name}

# Icons
pushd resources/icon
  install -D -m644 powder-256.png %{buildroot}%{_iconsdir}/hicolor/256x256/apps/%{name}.png
  install -D -m644 powder-48.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png
  install -D -m644 powder-32.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
  install -D -m644 powder-24.png %{buildroot}%{_iconsdir}/hicolor/24x24/apps/%{name}.png
  install -D -m644 powder-16.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
popd

# Desktop entry
install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=The Powder Toy
GenericName=Physics sandbox
Comment=Falling-sand physics sandbox game
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;Simulation;
EOF

%files
%doc LICENSE README.md
%{_gamesbindir}/%{name}
%{_libexecdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png


%changelog
* Mon Nov 07 2022 ghibo <ghibo> 96.2.350-1.mga9
+ Revision: 1904519
- Fix meson x86_sse argument
- Update to release 96.2.350.
- Switch to meson and fix BRs.
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Feb 27 2020 daviddavid <daviddavid> 95.0-1.mga8
+ Revision: 1550975
- new version: 95.0
- switch to luajit

* Sat Feb 15 2020 umeabot <umeabot> 94.1-2.mga8
+ Revision: 1525373
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Apr 14 2019 daviddavid <daviddavid> 94.1-1.mga7
+ Revision: 1389918
- new version: 94.1
- switch to sdl2

* Sun Sep 23 2018 umeabot <umeabot> 93.3-2.mga7
+ Revision: 1300355
- Mageia 7 Mass Rebuild

* Mon May 14 2018 akien <akien> 93.3-1.mga7
+ Revision: 1229454
- Version 93.3
- Version 92.5

* Mon Oct 02 2017 daviddavid <daviddavid> 92.1.332-2.mga7
+ Revision: 1162467
- patch1: fix build with scons 3.0

* Sat Aug 26 2017 akien <akien> 92.1.332-1.mga7
+ Revision: 1148041
- Version 92.1.332

* Sat Aug 13 2016 akien <akien> 91.5.330-1.mga6
+ Revision: 1046149
- Version 91.5.330

* Sun Apr 24 2016 akien <akien> 91.3.328-1.mga6
+ Revision: 1005860
- Version 91.3.328

* Thu Dec 24 2015 pterjan <pterjan> 90.2.322-4.mga6
+ Revision: 914036
- On i586 the binary gets renamed -legacy when sse is disabled...
- Only enable SSE/SSE2 for x86_64, arm really doesn't like it

* Thu Dec 24 2015 daviddavid <daviddavid> 90.2.322-2.mga6
+ Revision: 914008
- compile with debug symbols adding --debugging scons option

* Mon Jan 26 2015 akien <akien> 90.2.322-1.mga5
+ Revision: 812353
- imported package powdertoy

